@echo off

echo:
echo nginx for Windows http://nginx-win.ecsds.eu/
echo:
echo This script will create an User and a Service for nginx (for Windows).
echo Once the User has been created make sure you allow and/or deny access to
echo   other folders and/or files the nginx Service requires or are NOT
echo   required on a User level.
echo For example the nginx log folder must be writable for the User.
echo A default created user is a member of 'users' which have limited access,
echo   this script makes no attempt to limit this any further, you are
echo   encouraged to do this yourself.
echo:
echo This script also assumes nginx is already installed (extracted from
echo   the .zip archive) in c:\nginxwin
echo:
pause

cd /d "%~dp0"

set NG_Password=%RANDOM%%PROCESSOR_REVISION%
set NG_Username=nginx-win
set NG_Path=c:\nginxwin
set NG_PathR=c:\\nginxwin
set NG_Exec=nginx.exe
set NG_CfgPath=conf\nginx.conf
set NG_Servname=nginxwin
set NG_Desc=nginx for Windows
set NG_Password=%NG_Password%%RANDOM%

echo Checking values...
rem checking values
if exist %NG_Path%\%NG_Exec% goto c1
echo The file and/or path %NG_Path%\%NG_Exec% does not exist. Exit.
goto end
:c1
if exist %NG_Path%\%NG_CfgPath% goto c2
echo There is no configuration file %NG_Path%\%NG_CfgPath% . Exit.
goto end
:c2

echo Creating nginx user...
rem Create a user
net user %NG_Username% %NG_Password% /add
net user %NG_Username% /expires:never
WMIC USERACCOUNT WHERE "Name='%NG_Username%'" SET PasswordExpires=FALSE
cacls %NG_Path%\logs /t /e /c /g %NG_Username%:F
copy /b/y srvany.exe %NG_Path%
copy /b/y sleep.exe %NG_Path%

rem Add user to a specific group, currently disabled
rem net localgroup group_name %NG_Username% /add

echo Creating nginx service...
rem Create the service
sc create %NG_Servname% binPath= %NG_Path%\srvany.exe start= auto obj= %COMPUTERNAME%\%NG_Username% password= %NG_Password% DisplayName= "%NG_Desc%"
ntrights +r SeServiceLogonRight -u "%COMPUTERNAME%\%NG_Username%"

echo Creating scripts for reload, start and stop...
rem Create a reload config script
echo @echo off>%NG_Path%\ngx_reloadconfig.cmd
echo cd /d %NG_Path%>>%NG_Path%\ngx_reloadconfig.cmd
echo runas /savecred /env /user:%NG_Username% "nginx -s reload">>%NG_Path%\ngx_reloadconfig.cmd
echo sleep 4>>%NG_Path%\ngx_reloadconfig.cmd
echo runas /savecred /env /user:%NG_Username% "nginx -s reopen">>%NG_Path%\ngx_reloadconfig.cmd

rem Create a stop script
echo @echo off>%NG_Path%\ngx_stop.cmd
echo cd /d %NG_Path%>>%NG_Path%\ngx_stop.cmd
echo runas /savecred /env /user:%NG_Username% "nginx -s stop">>%NG_Path%\ngx_stop.cmd
echo sleep 5>>%NG_Path%\ngx_stop.cmd
echo net stop %NG_Servname%>>%NG_Path%\ngx_stop.cmd
echo TASKKILL /F /IM "nginx*">>%NG_Path%\ngx_stop.cmd

rem Create a start script
echo @echo off>%NG_Path%\ngx_start.cmd
echo cd /d %NG_Path%>>%NG_Path%\ngx_start.cmd
echo net start %NG_Servname%>>%NG_Path%\ngx_start.cmd

rem Create a test script
echo @echo off>%NG_Path%\ngx_test.cmd
echo cd /d %NG_Path%>>%NG_Path%\ngx_test.cmd
echo :loop>>%NG_Path%\ngx_test.cmd
echo nginx -t>>%NG_Path%\ngx_test.cmd
echo echo:>>%NG_Path%\ngx_test.cmd
echo pause>>%NG_Path%\ngx_test.cmd
echo goto loop>>%NG_Path%\ngx_test.cmd

echo Creating service registry changes and applying them...
rem Create registry changes
echo REGEDIT4>%NG_Path%\ngx_regvals.reg
echo:>>%NG_Path%\ngx_regvals.reg
echo [HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\%NG_Servname%\Parameters]>>%NG_Path%\ngx_regvals.reg
echo "Application"="%NG_PathR%\\%NG_Exec%">>%NG_Path%\ngx_regvals.reg
echo "AppParameters"="">>%NG_Path%\ngx_regvals.reg
echo "AppDirectory"="%NG_PathR%">>%NG_Path%\ngx_regvals.reg
regedit /s %NG_Path%\ngx_regvals.reg

echo:
echo All done !
echo Now run the ngx_stop.cmd once in order to initialize the /savecred
echo feature and use the Password: %NG_Password%
:end
pause
